Index: gnu/kawa/ant/ChangeLog
===================================================================
--- gnu/kawa/ant/ChangeLog	(revision 8487)
+++ gnu/kawa/ant/ChangeLog	(working copy)
@@ -1,3 +1,9 @@
+2015-06-02  Jamison Hope  <jrh@theptrgroup.com>
+
+	* Kawac.java (getMapper): Add file name mangling step to replace
+	"-" with "$Mn", so that Kawac looks for the right class files for
+	hyphenated source file names.
+
 2014-01-05  Per Bothner  <per@bothner.com>
 
 	* Makefile.am: Merge into ../../../gnu/Makefile.am and remove.
Index: gnu/kawa/ant/Kawac.java
===================================================================
--- gnu/kawa/ant/Kawac.java	(revision 8487)
+++ gnu/kawa/ant/Kawac.java	(working copy)
@@ -37,6 +37,7 @@
 import org.apache.tools.ant.types.selectors.SelectSelector;
 import org.apache.tools.ant.types.selectors.SizeSelector;
 import org.apache.tools.ant.types.selectors.modifiedselector.ModifiedSelector;
+import org.apache.tools.ant.util.ChainedMapper;
 import org.apache.tools.ant.util.CompositeMapper;
 import org.apache.tools.ant.util.FileNameMapper;
 import org.apache.tools.ant.util.GlobPatternMapper;
@@ -755,6 +756,30 @@
     }
   }
 
+  private static class MangleFileNameMapper implements FileNameMapper {
+    // A simplified version of Language.mangleNameIfNeeded().
+    private String mangleNameIfNeeded(String name) {
+      if (name == null || !name.contains("-")) return name;
+      int len = name.length();
+      StringBuffer mangled = new StringBuffer(len);
+      for (int i  = 0; i < len; ++i) {
+        char ch = name.charAt(i);
+        if (ch == '-') mangled.append("$Mn");
+        else mangled.append(ch);
+      }
+      return mangled.toString();
+    }
+
+    public String[] mapFileName(String sourceFileName) {
+      String mangled = mangleNameIfNeeded(sourceFileName);
+      if (mangled == null) return null;
+      return new String[] { mangled };
+    }
+    public void setFrom(String from) {}
+    public void setTo(String to) {}
+    public static MangleFileNameMapper INSTANCE = new MangleFileNameMapper();
+  }
+
   /**
    * Compares the language property to each of the given strings, and
    * returns true if there is a match.
@@ -805,7 +830,10 @@
     GlobPatternMapper m = new GlobPatternMapper();
     m.setFrom("*" + ext);
     m.setTo("*.class");
-    return m;
+    ChainedMapper c = new ChainedMapper();
+    c.add(m);
+    c.add(MangleFileNameMapper.INSTANCE);
+    return c;
   }
 
   /**
